@@ -30,16 +30,16 @@ Author: Igor van Loo
 
 def fibonacci(n):
     '''
-    Finds the n-th fibonnaci using matrix exponentiation
+    Finds the n-th Fibonacci using matrix exponentiation
     Method is outlined `here <https://stackoverflow.com/questions/18172257/efficient-calculation-of-fibonacci-series/23462371#23462371>`_
 
     :param n: An integer
 
-    :returns: The n-th fibonnaci number
+    :returns: The n-th Fibonacci number
     
     .. code-block:: python
     
-        fibonacci(100) = 354224848179261915075
+        print(fibonacci(100)) #354224848179261915075
     '''
     if type(n) != int:
         return "n must be an integer"
@@ -53,7 +53,7 @@ def fibonacci(n):
 
 def fib_till(limit):
     '''
-    Finds all fibonnaci number up till a limit
+    Finds all Fibonacci number up till a limit
 
     :param limit: An integer
 
@@ -61,8 +61,8 @@ def fib_till(limit):
     
     .. code-block:: python
     
-        fib_till(100) = [1, 1, 2, 3, 5, 8, 13, 21, 34, 55, 89]
-        sum(fib_till(1000)) = 2583
+        print(fib_till(100)) #[1, 1, 2, 3, 5, 8, 13, 21, 34, 55, 89]
+        print(sum(fib_till(1000))) #2583
         
     '''
     if type(limit) != int:
@@ -84,7 +84,7 @@ def ZeckendorfRepresentation(x):
     
     .. code-block:: python
         
-        ZeckendorfRepresentation(64) = [55, 8, 1]
+        print(ZeckendorfRepresentation(64)) #[55, 8, 1]
 
     '''
     if type(x) != int:
